==> hibernate-tools-5.2.13.Final-sources.jar: org/hibernate/tool/hbm2x/xml/AbstractXMLPrettyPrinterStrategy.java <==
package org.hibernate.tool.hbm2x.xml;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;
import java.io.ByteArrayInputStream;
import java.io.IOException;

public abstract class AbstractXMLPrettyPrinterStrategy implements XMLPrettyPrinterStrategy {

    protected Document newDocument(String xml, String encoding) throws SAXException, IOException, ParserConfigurationException {
    	final DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
    	dbf.setFeature("http://apache.org/xml/features/nonvalidating/load-external-dtd", false);
        final Document document = dbf
                .newDocumentBuilder()
                .parse(new InputSource(new ByteArrayInputStream(xml.getBytes(encoding))));
        document.normalize();
        return document;
    }

    protected void removeWhitespace(final Document document) throws XPathExpressionException {
        XPath xPath = XPathFactory.newInstance().newXPath();
        NodeList nodeList = (NodeList) xPath.evaluate("//text()[normalize-space()='']",
                document,
                XPathConstants.NODESET);

        for (int i = 0; i < nodeList.getLength(); ++i) {
            Node node = nodeList.item(i);
            node.getParentNode().removeChild(node);
        }
    }
}

==> hibernate-tools-5.4.20.Final-sources.jar: org/hibernate/tool/hbm2x/xml/AbstractXMLPrettyPrinterStrategy.java <==
package org.hibernate.tool.hbm2x.xml;

import org.hibernate.tool.api.xml.XMLPrettyPrinterStrategy;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;
import java.io.ByteArrayInputStream;
import java.io.IOException;

public abstract class AbstractXMLPrettyPrinterStrategy implements XMLPrettyPrinterStrategy {

    protected Document newDocument(String xml, String encoding) throws SAXException, IOException, ParserConfigurationException {
        final Document document = DocumentBuilderFactory.newInstance()
                .newDocumentBuilder()
                .parse(new InputSource(new ByteArrayInputStream(xml.getBytes(encoding))));
        document.normalize();
        return document;
    }

    protected void removeWhitespace(final Document document) throws XPathExpressionException {
        XPath xPath = XPathFactory.newInstance().newXPath();
        NodeList nodeList = (NodeList) xPath.evaluate("//text()[normalize-space()='']",
                document,
                XPathConstants.NODESET);

        for (int i = 0; i < nodeList.getLength(); ++i) {
            Node node = nodeList.item(i);
            node.getParentNode().removeChild(node);
        }
    }
}
